import { BaseConfigurable } from '../config/base-configurable';
import { BaseConfigurableImpl } from '../config/base-configurable-impl.service';
import { NgForageOptions } from '../config/ng-forage-options';
import { DriverType } from '../misc/driver-type.type';
import { Driver } from '../misc/driver.enum';
/**
 * Cache instance
 */
export declare class NgForage extends BaseConfigurableImpl implements BaseConfigurable {
    /**
     * Returns the name of the driver being used, or null if none can be used.
     */
    readonly activeDriver: DriverType;
    /**
     * Removes every key from the database, returning it to a blank slate.
     *
     * clear() will remove <b>every item in the offline store</b>. Use this method with caution.
     */
    clear(): Promise<void>;
    /**
     * Make a clone of the instance
     * @param config Optional configuration
     */
    clone(config?: NgForageOptions): NgForage;
    /**
     * Gets an item from the storage library.
     * If the key does not exist, getItem() will return null.
     * @param key Data key
     */
    getItem<T>(key: string): Promise<T>;
    /**
     * Iterate over all value/key pairs in datastore.
     * <i>iteratee</i> is called once for each pair, with the following arguments:
     * <ol>
     *   <li>Value</li>
     *   <li>Key</li>
     *   <li>iterationNumber - one-based number</li>
     * </ol>
     * iterate() supports early exit by returning non undefined value inside iteratorCallback callback.
     * @param iteratee
     */
    iterate<T, U>(iteratee: (value: T, key: string, iterationNumber: number) => U): Promise<U>;
    /**
     * Get the name of a key based on its ID.
     * @param index
     */
    key(index: number): Promise<string>;
    /**
     * Get the list of all keys in the datastore.
     */
    keys(): Promise<string[]>;
    /**
     * Gets the number of keys in the offline store (i.e. its “length”).
     */
    length(): Promise<number>;
    /**
     * Even though localForage queues up all of its data API method calls,
     * ready() provides a way to determine whether the asynchronous driver initialization process has finished.
     * That’s useful in cases like when we want to know which driver localForage has settled down using.
     */
    ready(): Promise<void>;
    /**
     * Removes the value of a key from the offline store.
     * @param key Data key
     */
    removeItem(key: string): Promise<void>;
    /**
     * Saves data to an offline store. You can store the following types of JavaScript objects:
     * <ul>
     *  <li>Array</li>
     *  <li>ArrayBuffer</li>
     *  <li>Blob</li>
     *  <li>Float32Array</li>
     *  <li>Float64Array</li>
     *  <li>Int8Array</li>
     *  <li>Int16Array</li>
     *  <li>Int32Array</li>
     *  <li>Number</li>
     *  <li>Object</li>
     *  <li>Uint8Array</li>
     *  <li>Uint8ClampedArray</li>
     *  <li>Uint16Array</li>
     *  <li>Uint32Array</li>
     *  <li>String</li>
     * </ul>
     * @param key Data key
     * @param data Data
     */
    setItem<T>(key: string, data: T): Promise<T>;
    /**
     * Check whether the given driver is supported/registered.
     * @param driver Driver name
     */
    supports(driver: Driver | string): boolean;
}
